#!/perl/bin/perl

# PERL script to demonstrate the DOW (Day of Week) function
# Written by James Greene, Lrrach, Germany
# Copyright (C) 1998 James Greene Informatics Consulting
# Based upon the dayofweek() function published in the comp.lang.c
# FAQ.

use strict;

#;---------------------------------------------------------------------------
#; DOW - Compute the Day of Week using Zeller's congruence (see the sci.math
#;   FAQ list). This is based upon the C code developed by Tomohiko Sakamoto,
#;   and converted to PERL by James Greene
#; Call with:
#;   $dow = &DOW($year, $month, $day) ;
#; Returns:
#;   0=Sunday, 1=Monday, ... 6=Saturday
#; This function is valid from the year that the Gregorian Calendar was
#; corrected (sometime in the middle ages).

sub DOW {
    my ($y, $m, $d) = @_ ;
    my @t = (0, 3, 2, 5, 0, 3, 5, 1, 4, 6, 2, 4) ;

    $y-- if ($m < 3) ;

    return ($y + $y/4 - $y/100 + $y/400 + $t[$m-1] + $d) % 7 ;
}

#;---------------------------------------------------------------------------
#; minmax - ensure that a value is within a given range

sub minmax {
    my ($min, $val, $max) = @_ ;
    $val = $min if ($val < $min) ;
    $val = $max if ($val > $max) ;
    return $val ;
}

#;---------------------------------------------------------------------------

my ($day, $mon, $year);

$day = defined($ARGV[0]) ? $ARGV[0] : 1;
$day = minmax(1, $day, 31);

$mon = defined($ARGV[1]) ? $ARGV[1] : 1;
$mon = minmax(1, $mon, 12) ; ;

$year = defined($ARGV[2]) ? $ARGV[2] : 1970;
$year += 1900 if ($year < 100) ;

my @Days = ("Sunday", "Monday", "Tuesday", "Wednesday",
            "Thursday", "Friday", "Saturday") ;
my @Month = ("",
             "Jan", "Feb", "Mar", "Apr", "May", "Jun",
             "Jul", "Aug", "Sep", "Oct", "Nov", "Dec") ;

print "$Days[DOW($year, $mon, $day)], $day. $Month[$mon] $year\n" ;

#;---------------------------------------------------------------------------

